Package: Meanimiles
Title: Estimation of Meanimiles
Version: 0.1.0
Authors@R: c(
    person("Dieter", "Debrauwer", , "dieter.debrauwer@kuleuven.be", role = c("aut", "cre","cph"),
    comment=c(ORCID="0000-0002-0171-1045")),
     person("Irène", "Gijbels",, email = "irene.gijbels@kuleuven.be", role = "ctb",
           comment = c(ORCID = "0000-0002-4443-9803")),
    person("Klaus", "Herrmann",, email = "klaus.herrmann@usherbrooke.ca", role = "ctb",
    comment = c(ORCID = "0000-0002-8044-5717")))
Description: Provides a comprehensive suite of estimation tools for meanimiles, 
    a general class of (risk) functionals. This package includes nonparametric 
    estimators for univariate meanimile evaluation, copula-based estimation 
    for portfolio risk aggregation (full parametric, semiparametric, and nonparametric),
    and novel estimators for meanimiles in regression settings. 
    Following the articles D. Debrauwer, I. Gijbels, and K. Herrmann (2025)
    <doi:10.1214/25-EJS2391>, D. Debrauwer and I. Gijbels (2026)
    <doi:10.1007/s00184-026-01022-9>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://github.com/DieterDebrauwer/Meanimiles
BugReports: https://github.com/DieterDebrauwer/Meanimiles/issues
Depends: R (>= 4.5.0)
Imports: copula (>= 1.1.7), fitdistrplus (>= 1.2.6), stats
Suggests: knitr, rmarkdown
NeedsCompilation: no
Packaged: 2026-04-16 14:24:40 UTC; u0156046
Author: Dieter Debrauwer [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-0171-1045>),
  Irène Gijbels [ctb] (ORCID: <https://orcid.org/0000-0002-4443-9803>),
  Klaus Herrmann [ctb] (ORCID: <https://orcid.org/0000-0002-8044-5717>)
Maintainer: Dieter Debrauwer <dieter.debrauwer@kuleuven.be>
Repository: CRAN
Date/Publication: 2026-04-21 18:42:45 UTC
Built: R 4.6.0; ; 2026-04-26 04:09:29 UTC; unix
